==> fantacalciobazar_0.2.1.tar.gz: fantacalciobazar/crea_giornata.php <==
<?php

################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
################################################################################

include("head.php");

include("controlla_pass.php");
if ($pass_admin_errata == "NO") {

$num_lettere = strlen($giornata);
if ($num_lettere != 10) $inserire = "NO";
if (is_dir($giornata)) $inserire = "NO";

if ($creare == "NO") echo "ERRORE<br>";
else {

mkdir($giornata, 0777);

$proprietario = "";
$ruolo  = "";
$nome = "";
$calciatori = file("mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$proprietario[$numero] = $dati_calciatore[4];
$ruolo[$numero] = $dati_calciatore[2];
$nome[$numero] = $dati_calciatore[1];
} # fine if ($sec_restanti < 0)
} # fine for $num1

$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$dati_squadra = @file("squadra_$giocatore");
$titolari_veri = "";
$num_titolari_veri = 0;
$panchinari_veri = "";
$num_panchinari_veri = 0;
$titolari = explode(",", $dati_squadra[1]);
$num_titolari = count($titolari);
$panchinari = explode(",", $dati_squadra[2]);
$num_panchinari = count($panchinari);
for ($num2 = 0 ; $num2 < $num_titolari; $num2++) {
$numero_titolare = $titolari[$num2];
$nome_titolare = $nome[$numero_titolare];
$ruolo_titolare = $ruolo[$numero_titolare];
if ($proprietario[$numero_titolare] == $giocatore) {
$titolari_veri .= "$numero_titolare,$nome_titolare,$ruolo_titolare
";
$num_titolari_veri++;
} # fine if ($proprietario[$numero_titolare] == $giocatore)
} # fine for $num2
for ($num2 = 0 ; $num2 < $num_panchinari; $num2++) {
$numero_panchinaro = $panchinari[$num2];
$nome_panchinaro = $nome[$numero_panchinaro];
$ruolo_panchinaro = $ruolo[$numero_panchinaro];
if ($proprietario[$numero_panchinaro] == $giocatore) {
$panchinari_veri .= "$numero_panchinaro,$nome_panchinaro,$ruolo_panchinaro
";
$num_panchinari_veri++;
} # fine if ($proprietario[$numero_titolare] == $giocatore)
} # fine for $num2
if ($num_titolari_veri < $min_num_titolari_in_formazione) {
$titolari_veri = "";
$panchinari_veri = "";
} # fine if ($num_titolari_veri < $min_num_titolari_in_formazione)
if ($num_panchinari_veri > $max_in_panchina) $panchinari_veri = "";
$fileformazione = fopen("$giornata/formazione_$giocatore","w+");
fwrite($fileformazione,"$titolari_veri
$panchinari_veri");
fclose($fileformazione);
next($pass);
} # fine for $num1
echo "$giornata creata!<br>";
} # fine else if ($creare == "NO")

echo "<form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form>";


} # fine if ($pass_admin_errata == "NO")

include("foot.php");
?>

==> fantacalciobazar_0.3.tar.gz: fantacalciobazar/crea_giornata.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

include("dati/head.php");

include("controlla_pass.php");
if ($pass_admin_errata == "NO") {

$lock = fopen("dati/admin.lock","w+");
flock($lock,2);

$num_lettere = strlen($giornata);
if ($num_lettere != 10) $creare = "NO";
if (is_file("dati/$giornata")) $creare = "NO";

if ($creare == "NO") echo "ERRORE<br>";
else {

#mkdir($giornata, 0777);
#chmod("$giornata", 0777);

$filegiornata = "";
$proprietario = "";
$ruolo  = "";
$nome = "";
$calciatori = file("dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$proprietario[$numero] = $dati_calciatore[4];
$ruolo[$numero] = $dati_calciatore[2];
$nome[$numero] = $dati_calciatore[1];
} # fine if ($sec_restanti < 0)
} # fine for $num1

$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$dati_squadra = @file("dati/squadra_$giocatore");
$titolari_veri = "";
$num_titolari_veri = 0;
$panchinari_veri = "";
$num_panchinari_veri = 0;
$titolari = explode(",", $dati_squadra[1]);
$num_titolari = count($titolari);
$panchinari = explode(",", $dati_squadra[2]);
$num_panchinari = count($panchinari);
for ($num2 = 0 ; $num2 < $num_titolari; $num2++) {
$numero_titolare = $titolari[$num2];
$nome_titolare = $nome[$numero_titolare];
$ruolo_titolare = $ruolo[$numero_titolare];
if ($proprietario[$numero_titolare] == $giocatore) {
$titolari_veri .= "$numero_titolare,$nome_titolare,$ruolo_titolare
";
$num_titolari_veri++;
} # fine if ($proprietario[$numero_titolare] == $giocatore)
} # fine for $num2
for ($num2 = 0 ; $num2 < $num_panchinari; $num2++) {
$numero_panchinaro = $panchinari[$num2];
$nome_panchinaro = $nome[$numero_panchinaro];
$ruolo_panchinaro = $ruolo[$numero_panchinaro];
if ($proprietario[$numero_panchinaro] == $giocatore) {
$panchinari_veri .= "$numero_panchinaro,$nome_panchinaro,$ruolo_panchinaro
";
$num_panchinari_veri++;
} # fine if ($proprietario[$numero_titolare] == $giocatore)
} # fine for $num2
if ($num_titolari_veri < $min_num_titolari_in_formazione) {
$titolari_veri = "";
$panchinari_veri = "";
} # fine if ($num_titolari_veri < $min_num_titolari_in_formazione)
if ($num_panchinari_veri > $max_in_panchina) $panchinari_veri = "";
$formazioni .= "#@& formazione #@&
$giocatore
$titolari_veri
$panchinari_veri
";    
next($pass);
} # fine for $num1

$filegiornata = fopen("dati/$giornata","w+");
fwrite($filegiornata,"$formazioni#@& fine formazioni #@&
");
fclose($filegiornata);


echo "$giornata creata!<br>";
} # fine else if ($creare == "NO")

flock($lock,3);
fclose($lock);

echo "<form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form>";


} # fine if ($pass_admin_errata == "NO")

include("dati/foot.php");
?>
